@@ -1,4 +1,4 @@
-//  $Id: camera.hpp 694 2006-08-29 07:42:36Z hiker $
+//  $Id: camera.hpp 1153 2007-06-14 22:54:22Z hiker $
 //
 //  SuperTuxKart - a fun racing game with go-kart
 //  Copyright (C) 2004-2005 Steve Baker <sjbaker1@airmail.net>
@@ -21,33 +21,37 @@
 #ifndef HEADER_CAMERA_H
 #define HEADER_CAMERA_H
 
+class ssgContext;
+
 class Camera
 {
 public:
-  enum Mode {
-    CM_NORMAL,
-    CM_CLOSEUP,
-    CM_NO_FAKE_DRIFT,
-    CM_SIMPLE_REPLAY
-  };
+    enum Mode {
+        CM_NORMAL,
+        CM_CLOSEUP,
+        //FIXME: NO_FAKE_DRIFT is broken
+        CM_NO_FAKE_DRIFT,
+        CM_SIMPLE_REPLAY
+    };
 protected:
-  ssgContext *context  ;
+    ssgContext *m_context  ;
 
-  int    whichKart ;
-  Mode mode;
-  float last_steer_offset;
-  float x, y, w, h ;
+    int    m_which_kart ;
+    Mode m_mode;
+    float m_last_steer_offset;
+    float m_x, m_y, m_w, m_h ;
+    float m_LastPitch;
 
 public:
-  Camera ( int numPlayers, int id ) ;
+    Camera ( int numPlayers, int id ) ;
 
-  /** Set the camera to the given mode */
-  void setMode(Mode mode_);
+    /** Set the camera to the given mode */
+    void setMode(Mode mode_);
 
-  void setScreenPosition ( int numPlayers, int pos ) ;
+    void setScreenPosition ( int numPlayers, int pos ) ;
 
-  void update () ;
-  void apply  () ;
+    void update (float dt) ;
+    void apply  () ;
 } ;
 
 #endif
