@@ -1,4 +1,4 @@
-//  $Id: empty_screen.cpp 694 2006-08-29 07:42:36Z hiker $
+//  $Id: empty_screen.cpp 855 2006-11-17 01:50:37Z coz $
 //
 //  SuperTuxKart - a fun racing game with go-kart
 //  Copyright (C) 2006 SuperTuxKart-Team
@@ -17,30 +17,27 @@
 //  along with this program; if not, write to the Free Software
 //  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
-#include <plib/pw.h>
+#include <SDL/SDL.h>
 
 #include "empty_screen.hpp"
 #include "start_screen.hpp"
 #include "screen_manager.hpp"
 #include "gui/menu_manager.hpp"
-#include "plibdrv.hpp"
 
 EmptyScreen::EmptyScreen()
-{
-  pwSetCallbacks(keystroke, gui_mousefn, gui_motionfn, NULL, NULL);
-}
+{}
 
+//-----------------------------------------------------------------------------
 EmptyScreen::~EmptyScreen()
-{
-}
+{}
 
+//-----------------------------------------------------------------------------
 void
 EmptyScreen::update()
 {
-    pollEvents() ;
     menu_manager->update();
 
-    pwSwapBuffers();
+    SDL_GL_SwapBuffers();
 }
 
 /* EOF */
