@@ -1,4 +1,4 @@
-//  $Id: explosion.hpp 694 2006-08-29 07:42:36Z hiker $
+//  $Id: explosion.hpp 917 2007-02-26 04:47:07Z hiker $
 //
 //  SuperTuxKart - a fun racing game with go-kart
 //  Copyright (C) 2004 Steve Baker <sjbaker1@airmail.net>
@@ -20,21 +20,20 @@
 #ifndef HEADER_EXPLOSION_H
 #define HEADER_EXPLOSION_H
 
-class ssgSelector;
-class Projectile;
+#include <plib/sg.h>
 
-
-class Explosion : public ssgTransform {
- public:
-  int step ;
-  ssgSelector  *seq ;
+class Explosion : public ssgTransform
+{
+public:
+    int m_step ;
+    ssgSelector  *m_seq ;
 public:
 
-       Explosion(Projectile* p);
-  int  inUse    ()              {return (step >= 0); }
-  void init     (Projectile *p);
-  void update   (float delta_t);
-  bool hasEnded () {return step>=seq->getNumKids();}
+    Explosion(sgCoord* coord);
+    int  inUse    ()              {return (m_step >= 0); }
+    void init     (sgCoord *coord);
+    void update   (float delta_t);
+    bool hasEnded () {return m_step >= m_seq->getNumKids(); }
 
 } ;
 
