@@ -1,4 +1,4 @@
-//  $Id: base_gui.hpp 694 2006-08-29 07:42:36Z hiker $
+//  $Id: base_gui.hpp 1006 2007-04-17 07:36:44Z hiker $
 //
 //  SuperTuxKart - a fun racing game with go-kart
 //  Copyright (C) 2006 SuperTuxKart-Team
@@ -20,21 +20,22 @@
 #ifndef HEADER_BASEGUI_H
 #define HEADER_BASEGUI_H
 
+#include "player.hpp"
+
 class BaseGUI
 {
 public:
-	BaseGUI() {}
-	virtual ~BaseGUI() {}
+    BaseGUI() {}
+    virtual ~BaseGUI() {}
 
-	virtual void update(float dt);
-	virtual void select() = 0;
-	virtual void keybd(int key);
-	virtual void point(int x, int y);
-	virtual void stick(const int &whichAxis, const float &value);
-	virtual void joybuttons(int whichJoy, int hold, int presses, int releases);
+    virtual void update(float dt);
+    virtual void select() = 0;
 
+    virtual void input(InputType type, int id0, int id1, int id2, int value);
+    virtual void inputKeyboard(int key, int pressed);
+    void  TimeToString(const float time, char *s);
 protected:
-	int menu_id;
+    int m_menu_id;
 };
 
 #endif // HEADER_BASEGUI_H
