@@ -1,4 +1,4 @@
-//  $Id: char_sel.hpp 694 2006-08-29 07:42:36Z hiker $
+//  $Id: char_sel.hpp 906 2007-02-04 01:37:49Z coz $
 //
 //  SuperTuxKart - a fun racing game with go-kart
 //  Copyright (C) 2006 SuperTuxKart-Team
@@ -22,28 +22,27 @@
 
 #include "base_gui.hpp"
 
-class ssgBranch;
 class ssgTransform;
 class ssgContext;
 
 class CharSel: public BaseGUI
 {
 private:
-    ssgContext* context;
-    ssgTransform* kart;
-    int current_kart;
-    int kart_name_label;
-    float clock;
+    ssgContext* m_context;
+    ssgTransform* m_kart;
+    int m_current_kart;
+    int m_kart_name_label;
+    float m_clock;
+
+    int m_player_index;
 
-	int playerIndex;
-	
 public:
-	CharSel(int whichPlayer);
-	~CharSel();
-	
-    void switch_to_character(int n);
-	void update(float dt);
-	void select();
+    CharSel(int which_player);
+    ~CharSel();
+
+    void switchCharacter(int n);
+    void update(float dt);
+    void select();
 };
 
 #endif
