@@ -1,4 +1,4 @@
-//  $Id: config_display.hpp 694 2006-08-29 07:42:36Z hiker $
+//  $Id: config_display.hpp 854 2006-11-06 14:10:45Z coz $
 //
 //  SuperTuxKart - a fun racing game with go-kart
 //  Copyright (C) 2006 SuperTuxKart-Team
@@ -24,15 +24,16 @@
 
 class ConfigDisplay: public BaseGUI
 {
+    void CreateMenu();
 public:
-	ConfigDisplay();
-	~ConfigDisplay();
-	
-	void update(float dt);
-	void select();
+    ConfigDisplay();
+    ~ConfigDisplay();
+
+    void update(float dt);
+    void select();
 
 private:
-  int fullscreen_menu_id;
+    int m_fullscreen_menu_id;
 };
 
 #endif
