@@ -1,4 +1,4 @@
-//  $Id: config_sound.hpp 694 2006-08-29 07:42:36Z hiker $
+//  $Id: config_sound.hpp 854 2006-11-06 14:10:45Z coz $
 //
 //  SuperTuxKart - a fun racing game with go-kart
 //  Copyright (C) 2006 SuperTuxKart-Team
@@ -25,15 +25,15 @@
 class ConfigSound: public BaseGUI
 {
 public:
-	ConfigSound();
-	~ConfigSound();
+    ConfigSound();
+    ~ConfigSound();
 
     void update(float dt);
-	void select();
+    void select();
 
 private:
-  int music_menu_id;
-  int sfx_menu_id;
+    int m_music_menu_id;
+    int m_sfx_menu_id;
 };
 
 #endif
