@@ -1,4 +1,4 @@
-//  $Id: credits_menu.hpp 728 2006-09-04 13:25:10Z hiker $
+//  $Id: credits_menu.hpp 854 2006-11-06 14:10:45Z coz $
 //
 //  SuperTuxKart - a fun racing game with go-kart
 //  Copyright (C) 2006 Joerg Henrichs
@@ -27,16 +27,17 @@
 #include "player.hpp"
 
 
-class CreditsMenu: public ScrolledText {
+class CreditsMenu: public ScrolledText
+{
 protected:
-  int        xLeft, xRight, yBottom, yTop;
-  float      yPos, ySpeed;
-  int        numberOfLines;
-  int        fontSize;
-  StringList sl;
+    int        m_xLeft, m_xRight, m_yBottom, m_yTop;
+    float      m_yPos, m_ySpeed;
+    int        m_numberOfLines;
+    int        m_fontSize;
+    StringList m_string_list;
 public:
-       CreditsMenu();
-      ~CreditsMenu();
+    CreditsMenu();
+    ~CreditsMenu();
 };
 
 #endif
