@@ -1,4 +1,4 @@
-//  $Id: main_menu.hpp 694 2006-08-29 07:42:36Z hiker $
+//  $Id: main_menu.hpp 854 2006-11-06 14:10:45Z coz $
 //
 //  SuperTuxKart - a fun racing game with go-kart
 //  Copyright (C) 2006 SuperTuxKart-Team
@@ -25,11 +25,11 @@
 class MainMenu: public BaseGUI
 {
 public:
-	MainMenu();
-	~MainMenu();
+    MainMenu();
+    ~MainMenu();
 
-	void select();
-	void keybd(int key);
+    void select();
+    void inputKeyboard(int key, int pressed);
 };
 
 #endif
