@@ -1,4 +1,4 @@
-//  $Id: race_results_gui.hpp 694 2006-08-29 07:42:36Z hiker $
+//  $Id: race_results_gui.hpp 943 2007-03-28 02:20:44Z hiker $
 //
 //  SuperTuxKart - a fun racing game with go-kart
 //  Copyright (C) 2006 Eduardo Hernandez Munoz
@@ -25,13 +25,18 @@
 /** GUI that shows the RaceResults, times and such */
 class RaceResultsGUI : public BaseGUI
 {
- private:
-  char* score;
-public:
-  RaceResultsGUI();
-  ~RaceResultsGUI();
+private:
+    char* m_score;
+    char* m_highscores;
 
-  void select();
+public:
+    RaceResultsGUI();
+    ~RaceResultsGUI();
+
+    void select();
+
+    void input(InputType type, int id0, int  id1, int id2, int value);
+    void inputKeyboard(int key, int pressed);
 };
 
 #endif
