@@ -1,4 +1,4 @@
-//  $Id: track_sel.hpp 732 2006-09-05 12:33:26Z hiker $
+//  $Id: track_sel.hpp 854 2006-11-06 14:10:45Z coz $
 //
 //  SuperTuxKart - a fun racing game with go-kart
 //  Copyright (C) 2006 SuperTuxKart-Team
@@ -22,15 +22,16 @@
 
 #include "base_gui.hpp"
 
-class TrackSel: public BaseGUI {
+class TrackSel: public BaseGUI
+{
 protected:
-  int   rect;
+    int   m_rect;
 public:
-	TrackSel();
-	~TrackSel();
+    TrackSel();
+    ~TrackSel();
 
-	void update(float dt);
-	void select();
+    void update(float dt);
+    void select();
 };
 
 #endif
