@@ -1,4 +1,4 @@
-//  $Id: screen_manager.hpp 694 2006-08-29 07:42:36Z hiker $
+//  $Id: screen_manager.hpp 855 2006-11-17 01:50:37Z coz $
 //
 //  SuperTuxKart - a fun racing game with go-kart
 //  Copyright (C) 2004 Ingo Ruhnke <grumbel@gmx.de>
@@ -19,6 +19,7 @@
 
 #ifndef HEADER_SCREENMANAGER_H
 #define HEADER_SCREENMANAGER_H
+#include <stdlib.h>
 
 class Screen;
 
@@ -27,19 +28,20 @@ class Screen;
 class ScreenManager
 {
 private:
-  bool do_abort;
-  Screen* current_screen;
-  Screen* next_screen;
+    bool m_do_abort;
+    Screen* m_current_screen;
+    Screen* m_next_screen;
 
 public:
-  ScreenManager();
-  ~ScreenManager();
-  void run();
-  /** aborts the main loop */
-  void abort();
-  /** Set the current active screen, the screen will get delete'ed
-      automatically once it is no longer needed */
-  void setScreen(Screen* screen);
+    ScreenManager();
+    ~ScreenManager();
+    void run();
+    /** aborts the main loop */
+    void abort();
+    /** Set the current active screen, the screen will get delete'ed
+        automatically once it is no longer needed */
+    void setScreen(Screen* screen);
+    bool  screenSwitchPending() const {return m_next_screen!=NULL;}
 };
 
 extern ScreenManager* screen_manager;
