@@ -1,4 +1,4 @@
-//  $Id: start_screen.hpp 694 2006-08-29 07:42:36Z hiker $
+//  $Id: start_screen.hpp 855 2006-11-17 01:50:37Z coz $
 //
 //  SuperTuxKart - a fun racing game with go-kart
 //  Copyright (C) 2006 SuperTuxKart-Team
@@ -21,22 +21,21 @@
 #define HEADER_STARTSCREEN_H
 
 #include "screen.hpp"
-
-class ssgSimpleState;
+#include "material.hpp"
 
 
 class StartScreen : public Screen
 {
 private:
-  ssgSimpleState *introMaterial ;
+    Material *m_intro_material ;
 
-  void installMaterial();
 public:
-  StartScreen();
-  ~StartScreen();
-
-  void switchToGame();
-  void update(); 
+    StartScreen    ();
+    ~StartScreen    ();
+    void switchToGame   ();
+    void update         ();
+    void removeTextures ();
+    void installMaterial();
 };
 
 extern StartScreen* startScreen;
