@@ -1,4 +1,4 @@
-//  $Id: utils.cpp 694 2006-08-29 07:42:36Z hiker $
+//  $Id: utils.cpp 855 2006-11-17 01:50:37Z coz $
 //
 //  SuperTuxKart - a fun racing game with go-kart
 //  Copyright (C) 2004 Steve Baker <sjbaker1@airmail.net>
@@ -21,17 +21,17 @@
 
 void pr_from_normal ( sgVec3 hpr, sgVec3 nrm )
 {
-  float sy = sin ( -hpr [ 0 ] * SG_DEGREES_TO_RADIANS ) ;
-  float cy = cos ( -hpr [ 0 ] * SG_DEGREES_TO_RADIANS ) ;
+    const float SY = sin ( -hpr [ 0 ] * SG_DEGREES_TO_RADIANS ) ;
+    const float CY = cos ( -hpr [ 0 ] * SG_DEGREES_TO_RADIANS ) ;
 
-  hpr[2] =  SG_RADIANS_TO_DEGREES * atan2 ( nrm[0] * cy - nrm[1] * sy, nrm[2] ) ;
-  hpr[1] = -SG_RADIANS_TO_DEGREES * atan2 ( nrm[1] * cy + nrm[0] * sy, nrm[2] ) ;
+    hpr[2] =  SG_RADIANS_TO_DEGREES * atan2 ( nrm[0] * CY - nrm[1] * SY, nrm[2] ) ;
+    hpr[1] = -SG_RADIANS_TO_DEGREES * atan2 ( nrm[1] * CY + nrm[0] * SY, nrm[2] ) ;
 }
 
-
+//-----------------------------------------------------------------------------
 void hpr_from_normal ( sgVec3 hpr, sgVec3 nrm )
 {
-  pr_from_normal ( hpr, nrm ) ;
-  hpr[0] = -SG_RADIANS_TO_DEGREES * atan2 ( nrm[0], nrm[1] ) ;
+    pr_from_normal ( hpr, nrm ) ;
+    hpr[0] = -SG_RADIANS_TO_DEGREES * atan2 ( nrm[0], nrm[1] ) ;
 }
 
