@@ -1,4 +1,4 @@
-//  $Id: world_screen.hpp 694 2006-08-29 07:42:36Z hiker $
+//  $Id: world_screen.hpp 855 2006-11-17 01:50:37Z coz $
 //
 //  SuperTuxKart - a fun racing game with go-kart
 //  Copyright (C) 2006 SuperTuxKart-Team
@@ -20,7 +20,6 @@
 #ifndef HEADER_WORLDSCREEN_H
 #define HEADER_WORLDSCREEN_H
 
-#include <plib/ul.h>
 #include "screen.hpp"
 
 
@@ -32,24 +31,24 @@ class WorldScreen : public Screen
 {
 private:
 
-  ulClock fclock ;
-  ulClock frameClock;
-  int     frameCount;
-  
-  typedef std::vector<Camera*> Cameras;
-  Cameras cameras;
+    ulClock m_fclock ;
+    ulClock m_frame_clock;
+    int     m_frame_count;
 
-  static WorldScreen* current_;
+    typedef std::vector<Camera*> Cameras;
+    Cameras m_cameras;
+
+    static WorldScreen* m_current_;
 public:
-  static WorldScreen* current() { return current_; }
+    static WorldScreen* current() { return m_current_; }
 
-  WorldScreen(const RaceSetup& racesetup);
-  virtual ~WorldScreen();
+    WorldScreen(const RaceSetup& racesetup);
+    virtual ~WorldScreen();
 
-  Camera* getCamera(int i) const;
+    Camera* getCamera(int i) const;
 
-  void draw();
-  void update();
+    void draw();
+    void update();
 };
 
 #endif
